<?php

namespace Drupal\skillset_inview\Controller;

use Drupal;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;

/**
 * Preview controller for the skillset_inview module.
 */
class SkillsetInviewPreviewController extends ControllerBase {

  /**
   * Embed the basic block on an admin page for preview.
   *
   * @return array
   *   returns render array
   */
  public function preview() {
    $db = Drupal::database();
    $query = $db->select('skillset_inview', 's')
      ->fields('s')
      ->execute()->fetchAll();
    $total_skills = count($query);
    if ($total_skills == 0) {
      drupal_set_message($this->t('Preview offline.  No skills exist at this time, please add below&hellip;'), 'warning');
      return new RedirectResponse(Drupal::url('skillset_inview.add_form'));
    }
    $block_manager = Drupal::service('plugin.manager.block');
    $config = [];
    $block_plugin = $block_manager->createInstance('skillset_inview_zero', $config);
    $block_build = $block_plugin->build();
    $block_content = Drupal::service('renderer')->render($block_build);

    $block_admin_link = [
      '#title' => $this->t('Block Structure'),
      '#attributes' => [
        'title' => "goto 'Block Structure' page",
      ],
      '#type' => 'link',
      '#url' => Url::fromRoute('block.admin_display'),
    ];

    $page = [
      'block_preview' => [
        '#type' => 'markup',
        '#markup' => $block_content,
      ],
      'help' => [
        '#type' => 'markup',
        '#markup' => '<footer class="preview-footer-note"><mark>' . $this->t('When your content is ready, place the <strong>Skillset Inview</strong> on the @blockStructure page.', [
          '@blockStructure' => Drupal::service('renderer')->render($block_admin_link),
        ]) . '</mark></footer>',
        '#attached' => [
          'library' => [
            'skillset_inview/skillset-inview.admin',
          ],
        ],
      ],
    ];
    if (!Drupal::currentUser()->hasPermission('administer blocks')) {
      unset($page['help']);
    }
    return $page;
  }

}
